define(['core_lib/alerts'], function(Alerts) {

  describe('Alert view', function() {

    it('shows the specified content when rendered', function() {
      var alert = new Alerts.alert({
        content: 'This is an alert'
      });

      alert.render();

      expect(alert.el.innerHTML).toMatch('This is an alert');
    });

    it('adds any additional classes when rendered', function() {
      var alert = new Alerts.alert({
        classes: ['klass']
      });

      alert.render();

      expect(alert.$el.hasClass('klass')).toBeTruthy();
    });

    it('should have a close button by default', function() {
      var alert = new Alerts.alert();

      alert.render();

      expect(alert.$('button[data-dismiss="alert"]').length).toBe(1);
    });

    it('should not show the close button if configured', function() {
      var alert = new Alerts.alert({
        hide_close_button: true
      });

      alert.render();

      expect(alert.$('button[data-dismiss="alert"]').length).toBe(0);
    });

    describe('specific alert types', function() {

      _.each(['error', 'warning', 'success', 'info'], function(type) {
        it(type + ' has the correct Bootstrap class', function() {
          var alert = new Alerts[type]();

          alert.render();

          expect(alert.$el.hasClass('alert-' + type)).toBeTruthy();
        });
      });

    });

  });

});